/** (C) Copyright 2010 Hal Hildebrand, All Rights Reserved
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 *     
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 */
package com.hellblazer.slp;

import java.io.Serializable;

/**
 * The service lifecycle event.
 * 
 * @author <a href="mailto:hal.hildebrand@gmail.com">Hal Hildebrand</a>
 * 
 */
public class ServiceEvent implements Serializable {
    public enum EventType {
        MODIFIED, REGISTERED, UNREGISTERED
    }

    private static final long      serialVersionUID = 1L;
    private final ServiceReference reference;
    private final EventType        type;

    public ServiceEvent(EventType type, ServiceReference reference) {
        this.type = type;
        this.reference = reference;
    }

    public ServiceReference getReference() {
        return reference;
    }

    public EventType getType() {
        return type;
    }

    @Override
    public String toString() {
        return "ServiceEvent [type=" + type + ", reference=" + reference + "]";
    }
}